﻿using System;
using System.ComponentModel;
using System.Diagnostics;
using System.Net.Http;
using System.Runtime.CompilerServices;
using System.Runtime.Serialization;
using System.Threading.Tasks;
using Newtonsoft.Json;

namespace DesignShared
{
    public class MainViewModel : INotifyPropertyChanged
    {
        private ChairInfo[] chairs;

        public ChairInfo[] Chairs
        {
            get { return chairs; }
            set
            {
                if (Chairs == value) return;
                chairs = value;
                OnPropertyChanged();
            }
        }

        public async Task LoadChairs()
        {
            try
            {
                var url =
                    "http://api.flickr.com/services/feeds/photos_public.gne?format=json&nojsoncallback=true&tags=chair";
                var http = new HttpClient();

                var str = await http.GetStringAsync(url);
                var data = JsonConvert.DeserializeObject<FlickrData>(str);
                Chairs = data.Chairs;
            }
            catch (Exception ex)
            {
                Debug.WriteLine(ex.Message);
            }


        }

        public event PropertyChangedEventHandler PropertyChanged;

        protected virtual void OnPropertyChanged([CallerMemberName] string propertyName = null)
        {
            PropertyChangedEventHandler handler = PropertyChanged;
            if (handler != null) handler(this, new PropertyChangedEventArgs(propertyName));
        }
    }

    [DataContract]
    public class FlickrData
    {
        [DataMember(Name = "items")]
        public ChairInfo[] Chairs { get; set; }
    }

    [DataContract]
    public class ChairInfo
    {
        [IgnoreDataMember]
        public string PhotoUrl { get { return Media != null ? Media.ImageUrl : null; } }
        [DataMember(Name = "title")]
        public string Caption { get; set; }

        [DataMember(Name = "media")]
        public MediaInfo Media { get; set; }

        [DataContract]
        public class MediaInfo
        {
            [DataMember(Name = "m")]
            public string ImageUrl { get; set; }
        }
    }
}
